@@ -128,7 +128,9 @@ diat_epid <- function(resultLoad, maxDistTaxa = 2){
 
 
   #PROGRESS BAR
-  pb <- txtProgressBar(min = 1, max = (lastcol-1), style = 3)
+  if (interactive()) {
+    pb <- txtProgressBar(min = 1, max = (lastcol-1), style = 3)
+  }
   for (sampleNumber in 1:(lastcol-1)){ #for each sample in the matrix
     #how many taxa will be used to calculate?
     # New in v0.0.8
@@ -140,10 +142,15 @@ diat_epid <- function(resultLoad, maxDistTaxa = 2){
     EPID20 <- (-4.75*EPID)+20
     epid.results[sampleNumber, ] <- c(EPID, EPID20,num_taxa)
     #update progressbar
-    setTxtProgressBar(pb, sampleNumber)
+    if (interactive()) {
+      setTxtProgressBar(pb, sampleNumber)
+    }
   }
   #close progressbar
-  close(pb)
+  if (interactive()) {
+    close(pb)
+  }
+
   #######--------EPID INDEX: END--------############
   #PRECISION RECORDING
   resultsPath <- resultLoad[[4]]
@@ -169,11 +176,15 @@ diat_epid <- function(resultLoad, maxDistTaxa = 2){
   for (i in 1:ncol(inclusionmatrix)){
     newinclusionmatrix[1:nrow(inclusionmatrix),i] <- as.character(inclusionmatrix[1:nrow(inclusionmatrix),i])
   }
-  if (nrow(newinclusionmatrix) > length(taxaIncluded)){
-    newinclusionmatrix[1:length(taxaIncluded), ncol(newinclusionmatrix)] <- taxaIncluded
-  } else {
-    newinclusionmatrix[1:nrow(newinclusionmatrix), ncol(newinclusionmatrix)] <- taxaIncluded
-  }
+  #check that taxaIncluded is at least 1
+  if (length(taxaIncluded) > 0) {
+    if (nrow(newinclusionmatrix) > length(taxaIncluded)){
+      newinclusionmatrix[1:length(taxaIncluded), ncol(newinclusionmatrix)] <- taxaIncluded
+    } else {
+      newinclusionmatrix[1:nrow(newinclusionmatrix), ncol(newinclusionmatrix)] <- taxaIncluded
+    }
+  } else{newinclusionmatrix[is.na(newinclusionmatrix) == FALSE] <- NA}
+
   inclusionmatrix <- newinclusionmatrix
   colnames(inclusionmatrix) <- colnamesInclusionMatrix
   inclusionmatrix <- inclusionmatrix[-(1:which(colnames(inclusionmatrix)=="Eco.Morpho")-1)]
@@ -189,11 +200,15 @@ diat_epid <- function(resultLoad, maxDistTaxa = 2){
   for (i in 1:ncol(exclusionmatrix)){
     newexclusionmatrix[1:nrow(exclusionmatrix),i] <- as.character(exclusionmatrix[1:nrow(exclusionmatrix),i])
   }
-  if (nrow(newexclusionmatrix) > length(taxaExcluded)){
-    newexclusionmatrix[1:length(taxaExcluded), ncol(newexclusionmatrix)] <- taxaExcluded
-  } else {
-    newexclusionmatrix[1:nrow(newexclusionmatrix), ncol(newexclusionmatrix)] <- taxaExcluded
-  }
+  #check that taxaExcluded is at least 1
+  if (length(taxaExcluded) > 0) {
+    if (nrow(newexclusionmatrix) > length(taxaExcluded)){
+      newexclusionmatrix[1:length(taxaExcluded), ncol(newexclusionmatrix)] <- taxaExcluded
+    } else {
+      newexclusionmatrix[1:nrow(newexclusionmatrix), ncol(newexclusionmatrix)] <- taxaExcluded
+    }
+  }else{newexclusionmatrix[is.na(newexclusionmatrix) == FALSE] <- NA}
+
   exclusionmatrix <- newexclusionmatrix
   colnames(exclusionmatrix) <- colnamesInclusionMatrix
   exclusionmatrix <- exclusionmatrix[-(1:which(colnames(exclusionmatrix)=="Eco.Morpho")-1)]
